"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createMenuGraphQL = void 0;
var _resolve = _interopRequireDefault(require("./utils/resolve"));
const createMenuGraphQL = () => {
  return {
    type: "graphql-schema",
    schema: {
      typeDefs: /* GraphQL */`
                type PbMenu {
                    id: ID
                    createdOn: DateTime
                    createdBy: PbCreatedBy
                    title: String
                    slug: String
                    description: String
                    items: [JSON]
                }

                input PbMenuInput {
                    id: ID
                    title: String!
                    slug: String!
                    description: String
                    items: [JSON]
                }

                # Response types
                type PbMenuResponse {
                    data: PbMenu
                    error: PbError
                }

                type PbMenuListResponse {
                    data: [PbMenu]
                    error: PbError
                }

                extend type PbQuery {
                    getMenu(slug: String!): PbMenuResponse
                    getPublicMenu(slug: String!): PbMenuResponse
                    listMenus: PbMenuListResponse

                    "Returns menu by given slug."
                    getMenuBySlug(slug: String!): PbMenuResponse
                }

                extend type PbMutation {
                    createMenu(data: PbMenuInput!): PbMenuResponse
                    updateMenu(slug: String!, data: PbMenuInput!): PbMenuResponse
                    deleteMenu(slug: String!): PbMenuResponse
                }
            `,
      resolvers: {
        PbQuery: {
          getMenu: async (_, args, context) => {
            return (0, _resolve.default)(() => {
              return context.pageBuilder.getMenu(args.slug);
            });
          },
          getPublicMenu: async (_, args, context) => {
            return (0, _resolve.default)(() => {
              return context.pageBuilder.getPublicMenu(args.slug);
            });
          },
          listMenus: async (_, __, context) => {
            return (0, _resolve.default)(() => {
              return context.pageBuilder.listMenus();
            });
          }
        },
        PbMutation: {
          createMenu: async (_, args, context) => {
            return (0, _resolve.default)(() => {
              return context.pageBuilder.createMenu(args.data);
            });
          },
          updateMenu: async (_, args, context) => {
            return (0, _resolve.default)(() => {
              return context.pageBuilder.updateMenu(args.slug, args.data);
            });
          },
          deleteMenu: async (_, args, context) => {
            return (0, _resolve.default)(() => {
              return context.pageBuilder.deleteMenu(args.slug);
            });
          }
        }
      }
    }
  };
};
exports.createMenuGraphQL = createMenuGraphQL;

//# sourceMappingURL=menus.gql.js.map